<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Autores</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>Navegador web leve baseado no Webkit</translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
￼&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;￼
p, li { white-space: pre-wrap; }
￼&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;￼
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>WebKit version: %1</source>
        <translation>Versão do Webkit: %1</translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation>Idiomas</translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation>Idiomas: em ordem de preferência:</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Para &amp;cima</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Para &amp;baixo</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Adicionar...</translation>
    </message>
</context>
<context>
    <name>AdBlockBlockedNetworkReply</name>
    <message>
        <source>Blocked by AdBlockRule: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockDialog</name>
    <message>
        <source>Add Custom Rule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Learn more about writing rules...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse Subscriptions...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AdBlock Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable AdBlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockManager</name>
    <message>
        <source>Custom Rules</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockModel</name>
    <message>
        <source>Rule</source>
        <translation type="unfinished">Regra</translation>
    </message>
</context>
<context>
    <name>AdBlockSchemeAccessHandler</name>
    <message>
        <source>Subscribe?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscribe to this AdBlock subscription?
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Adicionar favorito</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Escreva um nome para o favorito, e escolha onde deseja mantê-lo.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Adicionar pasta</translation>
    </message>
</context>
<context>
    <name>AutoFillDialog</name>
    <message>
        <source>Form Passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Remover</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillManager</name>
    <message>
        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never for this site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillModel</name>
    <message>
        <source>WebSite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>Abrir em nova aba</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>Editar nome</translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation>Editar endereço</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nova pasta</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Favoritos</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Adicionar pasta</translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Bookmarks Bar</source>
        <translation>Barra dos favoritos</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Menu favoritos</translation>
    </message>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Erro ao carregar os favoritos na linha %1, coluna %2:
%3</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Barra de ferramentas dos favoritos</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir arquivo</translation>
    </message>
    <message>
        <source>XBEL</source>
        <translation type="obsolete">XBEL</translation>
    </message>
    <message>
        <source>Error when loading html bookmarks: %1
</source>
        <translation type="obsolete">Erro ao carregar html de favoritos: %1
</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>Importado %1</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Salvar arquivo</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation>%1 Bookmarks.xbel</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml)</translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Erro ao exportar</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>Erro ao salvar favoritos</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Remover favorito</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Inserir favorito</translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation>Desfazer alteração no título do favorito</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation>Desfazer alteração na url do favorito</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation>Favoritos XBEL</translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation>Favoritos Netscape HTML</translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation>Ferramenta htmlToXBel é requerida</translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation>A ferramenta htmlToXBel, que é expedida com o Arora e é necessária para importar os favoritos HTML, não está instalada ou disponível nos caminhos de procura.</translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation>Carregando favoritos</translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation>Erro ao carregar os favoritos em HTML: %1
</translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation>Abrir em abas</translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Endereço</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">Favoritos</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Abrir em nova &amp;aba</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Adicionar ao favorito...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Adicionar pasta...</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Favoritos</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source> (Change: %1 %2)</source>
        <translation type="obsolete"> (Alteração: %1 %2)</translation>
    </message>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>Existem %1 janelas e %2 abas abertas.
Você quer sair de qualquer maneira?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>Falha ao restaurar</translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation type="obsolete">A sessão salva não será restaurada porque Arora fechou ao tentar restaurar esta sessão.</translation>
    </message>
    <message>
        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Arquivo</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>&amp;Nova janela</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>Abrir arquiv&amp;o...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>Abrir &amp;localização...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Salvar como...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>&amp;Importar favoritos...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>&amp;Exportar favoritos...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>Visualiza&amp;r impressão...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Im&amp;primir...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>Navegação pri&amp;vada...</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Fechar janela</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Desfazer</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Refazer</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Cor&amp;tar</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>C&amp;olar</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Locali&amp;zar</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>Pró&amp;ximo</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>Ante&amp;rior</translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation type="obsolete">Preferê&amp;ncias...</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation>Ctrl+,</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>E&amp;xibir</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Shift+Ctrl+B</source>
        <translation type="obsolete">Shift+Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Ctrl+/</translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>Mostrar barra de menu</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>&amp;Recarregar página</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Parar</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>A&amp;umentar zoom</translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation>Zoom &amp;normal</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Diminuir zoo&amp;m</translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation>Zoom somente do &amp;texto</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>F&amp;onte da página</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation>Ctrl+Alt+U</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Tela cheia</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>Hi&amp;stórico</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Avançar</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Página inicial</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Restaurar última sessão</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>Fa&amp;voritos</translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation>Mostrar todos os favoritos...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Adicionar ao favorito...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Adicionar pasta...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Janela</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Ferramentas</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>Pesqui&amp;sar na web</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>Limpar &amp;dados privados</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>Show &amp;Network Monitor</source>
        <translation type="obsolete">Mostrar mo&amp;nitor de rede</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>Habilitar &amp;inspetor web</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation>Trocar idiomar da aplicação</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Sobre &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation>Sobre o &amp;%1</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Navegação</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Mostrar barra de status</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Esconder barra de status</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Mostrar barra de ferramentas</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Esconder barra de ferramentas</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>Mostrar barra de favoritos</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>Esconder barra de favoritos</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>%1 - Arora</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Abrir recursos da web</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Recursos web (*.html *.htm *.svg *.png *.gif *.svgz);; Todos os arquivos (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Imprimir documento</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>Tem certeza que deseja ativar a navegação privada?</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Quando a navegação privada está ligada, algumas medidas relativas a sua privacidade serão desativadas:&lt;ul&gt;&lt;li&gt; As páginas web não serão adicionadas no histórico.&lt;/li&gt;&lt;li&gt; Itens serão automaticamente removidos da janela de Downloads.&lt;/li&gt;&lt;li&gt; Novos cookies não serão armazenados, cookies atuais não podem ser acessados.&lt;/li&gt;&lt;li&gt; Ícones de sites não serão armazenados, sessões não serão salvas.&lt;/li&gt;&lt;li&gt; Pesquisas não serão adicionadas para o menu popup na caixa de pesquisa.&lt;/li&gt;&lt;/ul&gt;Até você fechar a janela, você ainda pode clicar nos botões Voltar e Avançar para retornar às páginas que você tinha aberto.</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>Tem certeza que deseja fechar a janela? Existem %1 abas abertas</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>Inspetor web</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>O inspetor web só irá trabalhar corretamente para as páginas que foram carregadas após a habilitação.
Você deseja recarregar todas as páginas?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Interromper o carregamento da página atual</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Atualizar a página atual</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Texto codificado</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Selecionar &amp;Tudo</translation>
    </message>
    <message>
        <source>Alt+Ctrl+B</source>
        <translation>Alt+Ctrl+B</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;li&gt; No new network cache is written to disk.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Quando a navegação privada estiver ligada, algumas ações a respeito de sua privacidade serão desativadas: &lt;ul&gt;&lt;li&gt; As páginas web não serão adicionadas ao histórico.&lt;/li&gt;&lt;li&gt; Os itens serão automaticamente removidos da janela de Download.&lt;/li&gt;&lt;li&gt; Novos cookies não serão armazenados, e cookies atuais não poderão ser acessados.&lt;/li&gt;&lt;li&gt; Os ícones dos sites não serão armazenados, a sessão não será salva.&lt;/li&gt;&lt;li&gt; As pesquisas não serão adicionadas para o menu pop-up na caixa de pesquisa.&lt;/li&gt;&lt;li&gt; Nenhum novo cache de rede será escrito em disco.&lt;/li&gt;&lt;/ul&gt; Até você fechar a janela, você ainda pode clicar nos botões Voltar e Avançar para retornar às páginas que você abriu.</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="unfinished">Configurar mecanismos de pesquisa...</translation>
    </message>
    <message>
        <source>&amp;Ad Block...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webpages are not added to the history.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items are automatically removed from the Downloads window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Site icons won&apos;t be stored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session won&apos;t be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searches are not added to the pop-up menu in the search box.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No new network cache is written to disk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Private Browsing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Limpar dados privados</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>Limpar os seguintes itens:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>&amp;Histórico de navegação</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>Histórico de &amp;download</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>Histórico de pe&amp;squisa</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>&amp;Cookies</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>C&amp;ache das páginas web</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>Ícones de webs&amp;ites</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>Limpar dados &amp;privados</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation>Carregar</translation>
    </message>
    <message>
        <source>Load All</source>
        <translation>Carregar todos</translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation>Adicionar %1 à Lista branca</translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation>Remover da Lista branca</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation>Carregar flash</translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation>Sites de Lista branca</translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Website</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>Regra</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Permitir</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Permitir para sessão</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Website</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Caminho</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>Segurança</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Expira</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Sumário</translation>
    </message>
    <message>
        <source>true</source>
        <translation>verdadeiro</translation>
    </message>
    <message>
        <source>false</source>
        <translation>falso</translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation>Cookie da sessão</translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>Remover &amp;todos os cookies</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation>Adicionar &amp;regra</translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Exceções do cookie</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Nova exceção</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Domínio:</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Permitir para sessão</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Permitir</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Exceções</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Remover &amp;todos</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 itens</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">De</translation>
    </message>
    <message>
        <source>Ico</source>
        <translation>Ico</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Nome do arquivo</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Tentar novamente</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Salvar arquivo</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Download cancelado: %1</translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>Erro ao abrir o arquivo de saída: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Erro ao salvar: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Erro na rede: %1</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation>%1 de %2 (%3/seg) - %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 de %2 - Parado</translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation>O diretório de download (%1) não pôde ser criado.</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation>Existem %1 downloads em progresso.
Você deseja sair de qualquer maneira?</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n download</numerusform>
            <numerusform>%n downloads</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minutes remaining</source>
        <translation>
            <numerusform>%n minuto restante</numerusform>
            <numerusform>%n minutos restantes</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n seconds remaining</source>
        <translation>
            <numerusform>%n segundo restante</numerusform>
            <numerusform>%n segundos restantes</numerusform>
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>GB</source>
        <translation>GB</translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation>Nenhum erro</translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation>Erro ao abrir: %1: Nenhum arquivo ou diretório encontrado</translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation>Não foi possível ler %1</translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation>Conteúdo de %1</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 KB</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Histórico</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Remover &amp;todos</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Mostrar todos os históricos</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>Limpar histórico...</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Limpar histórico</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>Você deseja limpar o histórico?</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Endereço</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Hoje cedo</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n item</numerusform>
            <numerusform>%n itens</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation>Bem-vindoa ao Arora!</translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation>Iniciar Arora</translation>
    </message>
    <message>
        <source>Search!</source>
        <translation>Pesquisar!</translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation>Pesquisar resultados forneceidos por</translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation>Sobre Arora</translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>No translation files are installed.</source>
        <translation type="obsolete">Não estão instalados os arquivos de tradução.</translation>
    </message>
    <message>
        <source>Choose language</source>
        <translation>Escolha o idioma</translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation>&lt;p&gt;Você pode executar com um idioma diferente do que&lt; br&gt;o padrão do sistema operacional.&lt;/p&gt;&lt;p&gt;Por favor, escolha o idioma que deve ser utilizado&lt;/p&gt;</translation>
    </message>
    <message>
        <source>No translation files are installed at %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Digite o nome de usuário e senha para &quot;%1&quot; em %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Conectar no proxy &quot;%1&quot; usando:&lt;/qt&gt;</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation>- Erros SSL</translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Erros SSL:&lt;br/&gt;&lt;br/&gt;para: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Você deseja ignorar esses erros?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Certificados:&lt;br/&gt;%1&lt;br/&gt;Você deseja aceitar todos esses certificados?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation>Expedido por: %1</translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation>Sem validade não antes de: %1</translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation>Válido até: %1</translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation>Nomes alternativos:</translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Nome</translation>
    </message>
    <message>
        <source>Value</source>
        <translation type="obsolete">Valor</translation>
    </message>
</context>
<context>
    <name>NetworkMonitorDialog</name>
    <message>
        <source>Network Monitor</source>
        <translation type="obsolete">Monitor de rede</translation>
    </message>
    <message>
        <source>Network Requests</source>
        <translation type="obsolete">Pedidos da rede</translation>
    </message>
    <message>
        <source>Request Headers</source>
        <translation type="obsolete">Pedido dos cabeçalhos</translation>
    </message>
    <message>
        <source>Response Headers</source>
        <translation type="obsolete">Resposta dos cabeçalhos</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Remover</translation>
    </message>
    <message>
        <source>Remove &amp;All Requests</source>
        <translation type="obsolete">Remover &amp;todos os pedidos</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation>Abrir arquivo</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation>OpenSearch</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation>%1 não é uma válida descrição OpenSearch 1.1 ou já está em sua lista.</translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation>Você deve ter pelo menos um mecanismo de pesquisa aqui.</translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation>Gerenciar OpenSearch</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Excluir</translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation>&amp;Restaurar padrão</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation>&lt;strong&gt;Descrição:&lt;/strong&gt; %1</translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation>&lt;strong&gt;Exibir sugestões contextuais&lt;/strong&gt;</translation>
    </message>
    <message>
        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
        <translation>Lista separada por vírgulas de palavras-chave que podem ser inscritas na barra de endereços seguido de termos de procura para pesquisar com este mecanismo</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation>Palavras-chave</translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation>Você deseja adicionar o seguinte mecanismo para sua lista de mecanismos de pesquisa?&lt;br /&gt;&lt;br /&gt;Nome: %1&lt;br /&gt;Pesquisar sobre: %2</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Requer autenticação</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation>IMITAÇÃO DE ÍCONE</translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation>IMITAÇÃO DE INTRODUÇÃO DO TEXTO</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Usuário:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Não encontrado</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Autenticação no proxy</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Conectar-se no proxy</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Usuário:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation>O arquivo não é um arquivo OpenSearch 1.1.</translation>
    </message>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>O arquivo não é um arquivo XBEL versão 1.0.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Título desconhecido</translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Redirect: %1</source>
        <translation type="obsolete">Redirecionar: %1</translation>
    </message>
    <message>
        <source>Method</source>
        <translation type="obsolete">Método</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="obsolete">Endereço</translation>
    </message>
    <message>
        <source>Response</source>
        <translation type="obsolete">Resposta</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">Duração</translation>
    </message>
    <message>
        <source>Content Type</source>
        <translation type="obsolete">Tipo do conteúdo</translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="obsolete">Informação</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">De</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation>Testacar todos</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>Ao iniciar:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Mostrar minha página inicial</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Mostrar uma página em branco</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>Restaurar janelas e abas de última hora</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Página inicial:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Usar a página atual</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>Remover itens do histórico:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>Depois de um dia</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>Depois de uma semana</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>Depois de duas semanas</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>Depois de um mês</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>Depois de um ano</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>Manualmente</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>Na saída da aplicação</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Perguntar para um destino de cada vez</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Usar esse destino:</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Aparência</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Fonte padrão:</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Selecionar...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Fonte com largura fixa:</translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation>Idiomas preferenciais para visualização das páginas web:</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privacidade</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Conteúdo web</translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation>Boquear janelas instantâneas</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Habilitar plug-ins</translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation>Utilizar Clique para Instalar nos plug-ins flash</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Habilitar javascript</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>Ver imagens</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Aceitar cookies:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>Somente de sites que você navega</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Exceções...</translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>Manter cookie até:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>Ele expirar</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>Eu sair da aplicação</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>No máximo 90 dias</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Cookies...</translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation>Filtrar rastreamento de cookies</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Abas</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>Selecionar abas e janelas que são criadas</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation>Confirmar quando fechar múltiplas abas e janelas</translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation>Mostrar apenas um botão fechar, em vez de um para cada aba</translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation>Sair da aplicação quando a última aba for fechada</translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation>Abrindo links</translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation>Links que deseja abrir em uma nova janela:</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>Em uma nova janela</translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation>Em uma nova aba selecionada na janela atual</translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation>Em uma nova aba na janela atual</translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation>Na aba atual</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Abrir links de aplicações:</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Usar servidor proxy</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation>Socks5</translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation>Http (seguro)</translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation>Http (transparente)</translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>Servidor:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Porta:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Usuário:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>Folha de estilos:</translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation>Habilitar cache de rede</translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation>Tamanho máximo:</translation>
    </message>
    <message>
        <source> MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation>Utilizar o mecanismo de pesquisa padrão como retorno, quando a URL fornecida pelo usuário é inválida</translation>
    </message>
    <message>
        <source>Choose Directory...</source>
        <translation>Escolher diretório...</translation>
    </message>
    <message>
        <source>A cookie session ends:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When I exit the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>30 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill web forms:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User names and passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation>Requer reinício</translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation>A configuração do cache de rede foi modificada. Então, para que possa ser efetivado, o navegador deve ser reiniciado.</translation>
    </message>
    <message>
        <source>Choose Directory</source>
        <translation>Escolher diretório</translation>
    </message>
    <message>
        <source>Choose CSS File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation>Carregando...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Localizar</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="obsolete">&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Wrap lines</source>
        <translation type="obsolete">&amp;Separador</translation>
    </message>
    <message>
        <source>Source of Page </source>
        <translation type="obsolete">Fonte da página</translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation>Fonte da página %1</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>Show Tab Bar</source>
        <translation>Mostrar a barra de abas</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>Esconder a barra de abas</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Duplicar aba</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Fechar aba</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Fechar &amp;todas as abas</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Recarregar aba</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Recarregar todas as abas</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>Untitled</source>
        <translation>Sem título</translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation>Abas salvas</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>Você realmente deseja fechar essa página?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Você modificou esta página e quando fechá-la, você perderá a modificação.
Você realmente deseja fechar esta página?
</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Carregando...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation>Carregando %1% (%2 %3)...</translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation>Terminado carregamento</translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation>Falha ao carregar</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Mostrar próxima aba</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation>Ctrl-]</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Mostrar aba anterior</translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation>Ctrl-[</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Abas fechadas recentemente</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nova &amp;aba</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Fechar aba</translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation>Favorito de todas as abas</translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>Suggestions</source>
        <translation>Sugestões</translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation>Adicionar &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="obsolete">Configurar mecanismos de pesquisa...</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Limpar pesquisas recentes</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Sem pesquisas recentes</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Pesquisas recentes</translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>Erro ao carregar página: %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation>Ao conectar para: %1.</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation>Verifique o endereço se contém erros como &lt;b&gt;ww&lt;/b&gt;.arora-browser.org em vez de &lt;b&gt;www&lt;/b&gt;.arora-browser.org</translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation>Se o endereço está correto, tente verificar a conexão de rede.</translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation>Se o seu computador ou rede estão protegidos por um firewall ou proxy, certifique-se que o navegador tem permissão para acessar a rede.</translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation>Reenviando pedido POST</translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation>Para exibir o site, o pedido juntamente com todos os dados devem ser enviados mais uma vez, o que pode levar a alguns comportamentos inesperados do site por exemplo, a mesma ação pode ser realizada mais uma vez. Você deseja continuar mesmo assim?</translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>Abrir em nova &amp;janela</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Abrir em nova &amp;aba</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>Salvar lin&amp;k</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>&amp;Favorito desse link</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>&amp;Copiar localização do link</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>Abrir imagem em nova &amp;janela</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Abrir imagem em nova a&amp;ba</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>&amp;Salvar imagem</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>Copiar &amp;imagem</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>C&amp;opiar localização da imagem</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation>Pesquisar com...</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Carregando...</translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation>Adicionar para a barra de ferramentas de pesquisa</translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation>Método não suportado</translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation>%1 método não é suportado.</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Mecanismo de pesquisa</translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation>Escolha o mecanismo de pesquisa</translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation>Nome do mecanismo</translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation>Escreva um nome para o mecanismo</translation>
    </message>
    <message>
        <source>Block Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Não encontrado</translation>
    </message>
</context>
</TS>
